pub fn maybe_decrypt(
key: Option<&TokenEncryptionKey>,
stored: &str,
) -> Result<String, AuthError>Expand description
Attempt to decrypt stored if it carries an encryption sentinel.
Equivalent to maybe_decrypt_bound with empty AAD.
pub fn maybe_decrypt(
key: Option<&TokenEncryptionKey>,
stored: &str,
) -> Result<String, AuthError>Attempt to decrypt stored if it carries an encryption sentinel.
Equivalent to maybe_decrypt_bound with empty AAD.